@@ -22,7 +22,8 @@ func TestFillEmpty(t *testing.T) {
 		MuxOn:                              "8",
 		Mux:                                9,
 		Transparent:                        "10",
-		IntranetSharing:                    false,
+		IpForward:                          false,
+		PortSharing:                        false,
 		SpecialMode:                        "",
 		TransparentType:                    "",
 		AntiPollution:                      "",
