@@ -530,6 +530,13 @@ func (t *Template) AppendRoutingRuleByMode(mode configure.RulePortMode, inbounds
 				})
 		}
 		t.Routing.Rules = append(t.Routing.Rules,
+			coreObj.RoutingRule{
+				Type:        "field",
+				OutboundTag: "proxy",
+				InboundTag:  deepcopy.Copy(inbounds).([]string),
+				// https://github.com/v2rayA/v2rayA/issues/285
+				Domain: []string{"geosite:google"},
+			},
 			coreObj.RoutingRule{
 				Type:        "field",
 				OutboundTag: "direct",
@@ -589,7 +596,9 @@ func (t *Template) AppendRoutingRuleByMode(mode configure.RulePortMode, inbounds
 }
 
 func (t *Template) setRulePortRouting() error {
-	return t.AppendRoutingRuleByMode(t.Setting.RulePortMode, []string{"rule"})
+	// append rule-http and rule-socks no mather if they are enabled
+	// because "The Same as the Rule Port" may need them
+	return t.AppendRoutingRuleByMode(t.Setting.RulePortMode, []string{"rule-http", "rule-socks"})
 }
 func parseRoutingA(t *Template, routingInboundTags []string) error {
 	lines := strings.Split(configure.GetRoutingA(), "\n")
@@ -676,7 +685,7 @@ func parseRoutingA(t *Template, routingInboundTags []string) error {
 									UDP: false,
 								},
 								Sniffing: coreObj.Sniffing{
-									Enabled:      true,
+									Enabled:      false,
 									DestOverride: []string{"http", "tls"},
 								},
 							}
@@ -797,7 +806,7 @@ func parseRoutingA(t *Template, routingInboundTags []string) error {
 	t.Routing.Rules = append(t.Routing.Rules, coreObj.RoutingRule{
 		Type:        "field",
 		OutboundTag: defaultOutbound,
-		InboundTag:  []string{"rule"},
+		InboundTag:  []string{"rule-http", "rule-socks"},
 	})
 	return nil
 }
@@ -814,7 +823,7 @@ func (t *Template) setTransparentRouting() (err error) {
 		for i := range t.Routing.Rules {
 			ok := false
 			for _, in := range t.Routing.Rules[i].InboundTag {
-				if in == "rule" {
+				if in == "rule-http" {
 					ok = true
 					break
 				}
@@ -1011,8 +1020,9 @@ func (t *Template) setInbound() error {
 	if p != nil {
 		t.Inbounds[0].Port = p.Socks5
 		t.Inbounds[1].Port = p.Http
-		t.Inbounds[2].Port = p.HttpWithPac
-		vlessGrpc := &t.Inbounds[3]
+		t.Inbounds[2].Port = p.Socks5WithPac
+		t.Inbounds[3].Port = p.HttpWithPac
+		vlessGrpc := &t.Inbounds[4]
 		vlessGrpc.Port = p.VlessGrpc
 		if p.VlessGrpc > 0 {
 			if err := service.CheckGrpcSupported(); err != nil {
@@ -1448,7 +1458,7 @@ func (t *Template) setVlessGrpcRouting() {
 	for i := range t.Routing.Rules {
 		var bHasRule bool
 		for _, tag := range t.Routing.Rules[i].InboundTag {
-			if tag == "rule" {
+			if tag == "rule-http" {
 				bHasRule = true
 			}
 		}
@@ -1537,6 +1547,8 @@ func NewTemplate(serverInfos []serverInfo, setting *configure.Setting) (t *Templ
 	if t.API == nil {
 		t.SetAPI()
 	}
+	// set spare tire outbound. Fix: https://github.com/v2rayA/v2rayA/issues/447
+	t.Routing.Rules = append(t.Routing.Rules, coreObj.RoutingRule{Type: "field", Network: "tcp,udp", OutboundTag: "proxy"})
 
 	// set routing whitelist
 	var whitelist []Addr
@@ -1756,7 +1768,7 @@ func (t *Template) InsertMappingOutbound(o serverObj.ServerObj, inboundPort stri
 		Protocol: protocol,
 		Listen:   "0.0.0.0",
 		Sniffing: coreObj.Sniffing{
-			Enabled:      true,
+			Enabled:      false,
 			DestOverride: []string{"http", "tls"},
 		},
 		Settings: &coreObj.InboundSettings{
