@@ -27,7 +27,7 @@ func GetPingLatency(ctx *gin.Context) {
 	var wt []*configure.Which
 	err := jsoniter.Unmarshal([]byte(ctx.Query("whiches")), &wt)
 	if err != nil {
-		common.ResponseError(ctx, logError(nil, "bad request"))
+		common.ResponseError(ctx, logError("bad request"))
 		return
 	}
 	wt, err = service.Ping(wt, 1*time.Second)
@@ -58,7 +58,7 @@ func GetHttpLatency(ctx *gin.Context) {
 	var wt []*configure.Which
 	err := jsoniter.Unmarshal([]byte(ctx.Query("whiches")), &wt)
 	if err != nil {
-		common.ResponseError(ctx, logError(nil, "bad request"))
+		common.ResponseError(ctx, logError("bad request"))
 		return
 	}
 	wt, err = service.TestHttpLatency(wt, 8*time.Second, 4, false)
